@@ -11,6 +11,7 @@ import rdflib.plugins.sparql.processor
 from rdflib import Literal, URIRef
 import string
 import numbers
+from rdfhelpers.tinyrml import Mapper
 
 def identity(x):
     return x
@@ -105,7 +106,7 @@ class Composable:
             other = other._graph
         elif not isinstance(other, rdflib.Graph):
             raise ValueError("Cannot be added to a graph: {}".format(other))
-        return Composable(self._graph + other)
+        return self.__class__(self._graph + other)
 
     def add(self, *triples):
         for triple in triples:
@@ -133,3 +134,12 @@ class Composable:
     def update(self, template, **kwargs):
         Templated.update(self._graph, template, **kwargs)
         return self
+
+    def mapData(self, m, rows, **kwargs):
+        mapper = m if isinstance(m, Mapper) else Mapper(m, **kwargs)
+        mapper.process(rows, result_graph=self.result)
+        return self
+
+    def injectResult(self, target, context, function, **kwargs):
+        logging.warning("Adding data to graph {}".format(context))
+        return function(target, self.result, context, **kwargs)
